@@ -1,5 +1,4 @@
-# Copyright (C) 2003, 2004, 2005, 2006, 2008, 2009, 2010 Free Software
-# Foundation, Inc.
+# Copyright (C) 2003-2013 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,6 +14,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Automake::Variable;
+
+use 5.006;
 use strict;
 use Carp;
 
@@ -140,7 +141,7 @@ my @_var_order;
 
 # This keeps track of all variables defined by &_gen_varname.
 # $_gen_varname{$base} is a hash for all variables defined with
-# prefix `$base'.  Values stored in this hash are the variable names.
+# prefix '$base'.  Values stored in this hash are the variable names.
 # Keys have the form "(COND1)VAL1(COND2)VAL2..." where VAL1 and VAL2
 # are the values of the variable for condition COND1 and COND2.
 my %_gen_varname = ();
@@ -156,7 +157,6 @@ my %_gen_varname_n = ();
 # Macros accessible via aclocal.
 my %_am_macro_for_var =
   (
-   ANSI2KNR => 'AM_C_PROTOTYPES',
    CCAS => 'AM_PROG_AS',
    CCASFLAGS => 'AM_PROG_AS',
    EMACS => 'AM_PATH_LISPDIR',
@@ -169,7 +169,6 @@ my %_am_macro_for_var =
    pyexecdir => 'AM_PATH_PYTHON',
    PYTHON => 'AM_PATH_PYTHON',
    pythondir => 'AM_PATH_PYTHON',
-   U => 'AM_C_PROTOTYPES',
    );
 
 # Macros shipped with Autoconf.
@@ -186,6 +185,8 @@ my %_ac_macro_for_var =
    FCFLAGS => 'AC_PROG_FC',
    OBJC => 'AC_PROG_OBJC',
    OBJCFLAGS => 'AC_PROG_OBJC',
+   OBJCXX => 'AC_PROG_OBJCXX',
+   OBJCXXFLAGS => 'AC_PROG_OBJCXX',
    RANLIB => 'AC_PROG_RANLIB',
    UPC => 'AM_PROG_UPC',
    UPCFLAGS => 'AM_PROG_UPC',
@@ -316,21 +317,21 @@ use vars '%_variable_dict', '%_primary_dict';
 sub variables (;$)
 {
   my ($suffix) = @_;
+  my @vars = ();
   if ($suffix)
     {
       if (exists $_primary_dict{$suffix})
 	{
-	  return values %{$_primary_dict{$suffix}};
-	}
-      else
-	{
-	  return ();
+	  @vars = values %{$_primary_dict{$suffix}};
 	}
     }
   else
     {
-      return values %_variable_dict;
+      @vars = values %_variable_dict;
     }
+  # The behaviour of the 'sort' built-in is undefined in scalar
+  # context, hence we need an ad-hoc handling for such context.
+  return wantarray ? sort { $a->name cmp $b->name } @vars : scalar @vars;
 }
 
 =item C<Automake::Variable::reset>
@@ -470,10 +471,10 @@ sub _check_ambiguous_condition ($$$)
   # We allow silent variables to be overridden silently,
   # by either silent or non-silent variables.
   my $def = $self->def ($ambig_cond);
-  if ($message && !($def && $def->pretty == VAR_SILENT))
+  if ($message && $def->pretty != VAR_SILENT)
     {
       msg 'syntax', $where, "$message ...", partial => 1;
-      msg_var ('syntax', $var, "... `$var' previously defined here");
+      msg_var ('syntax', $var, "... '$var' previously defined here");
       verb ($self->dump);
     }
 }
@@ -527,7 +528,7 @@ sub output ($@)
   foreach my $cond (@conds)
     {
       my $def = $self->def ($cond);
-      prog_error ("unknown condition `" . $cond->human . "' for `"
+      prog_error ("unknown condition '" . $cond->human . "' for '"
 		  . $self->name . "'")
 	unless $def;
 
@@ -675,8 +676,8 @@ sub has_conditional_contents ($)
 
   # Traverse the variable recursively until we
   # find a variable defined conditionally.
-  # Use `die' to abort the traversal, and pass it `$full_cond'
-  # to we can find easily whether the `eval' block aborted
+  # Use 'die' to abort the traversal, and pass it '$full_cond'
+  # to we can find easily whether the 'eval' block aborted
   # because we found a condition, or for some other error.
   eval
     {
@@ -747,7 +748,7 @@ sub scan_variable_expansions ($)
     {
       my $var = $1 || $2;
       # The occurrence may look like $(string1[:subst1=[subst2]]) but
-      # we want only `string1'.
+      # we want only 'string1'.
       $var =~ s/:[^:=]*=[^=]*$//;
       push @result, $var;
     }
@@ -844,14 +845,14 @@ sub define ($$$$$$$$)
 			       || $pretty == VAR_SILENT
 			       || $pretty == VAR_SORTED);
 
-  error $where, "bad characters in variable name `$var'"
+  error $where, "bad characters in variable name '$var'"
     if $var !~ /$_VARIABLE_PATTERN/o;
 
-  # `:='-style assignments are not acknowledged by POSIX.  Moreover it
+  # ':='-style assignments are not acknowledged by POSIX.  Moreover it
   # has multiple meanings.  In GNU make or BSD make it means "assign
   # with immediate expansion", while in OSF make it is used for
   # conditional assignments.
-  msg ('portability', $where, "`:='-style assignments are not portable")
+  msg ('portability', $where, "':='-style assignments are not portable")
     if $type eq ':';
 
   check_variable_expansions ($value, $where);
@@ -880,11 +881,11 @@ sub define ($$$$$$$$)
       if ($def->type ne $type && $def->owner == VAR_AUTOMAKE)
 	{
 	  error ($def->location,
-		 "Automake variable `$var' was set with `"
-		 . $def->type . "=' here...", partial => 1);
-	  error ($where, "... and is now set with `$type=' here.");
+		 "Automake variable '$var' was set with '"
+		 . $def->type . "=' here ...", partial => 1);
+	  error ($where, "... and is now set with '$type=' here.");
 	  prog_error ("Automake variable assignments should be consistently\n"
-		      . "defined with the same sign.");
+		      . "defined with the same sign");
 	}
 
       # If Automake tries to override a value specified by the user,
@@ -894,15 +895,15 @@ sub define ($$$$$$$$)
 	  if (! exists $_silent_variable_override{$var})
 	    {
 	      my $condmsg = ($cond == TRUE
-			     ? '' : (" in condition `" . $cond->human . "'"));
+			     ? '' : (" in condition '" . $cond->human . "'"));
 	      msg_cond_var ('override', $cond, $var,
-			    "user variable `$var' defined here$condmsg...",
+			    "user variable '$var' defined here$condmsg ...",
 			    partial => 1);
 	      msg ('override', $where,
-		   "... overrides Automake variable `$var' defined here");
+		   "... overrides Automake variable '$var' defined here");
 	    }
 	  verb ("refusing to override the user definition of:\n"
-		. $self->dump ."with `" . $cond->human . "' => `$value'");
+		. $self->dump ."with '" . $cond->human . "' => '$value'");
 	  return;
 	}
     }
@@ -991,16 +992,16 @@ sub define ($$$$$$$$)
 	  #   endif
 	  #   X += Z
 	  # should be rejected because X is not defined for all conditions
-	  # where `+=' applies.
+	  # where '+=' applies.
 	  my $undef_cond = $self->not_always_defined_in_cond ($cond);
 	  if (! $undef_cond->false)
 	    {
 	      error ($where,
-		     "Cannot apply `+=' because `$var' is not defined "
+		     "cannot apply '+=' because '$var' is not defined "
 		     . "in\nthe following conditions:\n  "
 		     . join ("\n  ", map { $_->human } $undef_cond->conds)
-		     . "\nEither define `$var' in these conditions,"
-		     . " or use\n`+=' in the same conditions as"
+		     . "\neither define '$var' in these conditions,"
+		     . " or use\n'+=' in the same conditions as"
 		     . " the definitions.");
 	    }
 	  else
@@ -1027,7 +1028,7 @@ sub define ($$$$$$$$)
 	if ! $new_var && $owner < $def->owner;
 
       # Assignments to a macro set its location.  We don't adjust
-      # locations for `+='.  Ideally I suppose we would associate
+      # locations for '+='.  Ideally I suppose we would associate
       # line numbers with random bits of text.
       $def = new Automake::VarDef ($var, $value, $comment, $where->clone,
 				   $type, $owner, $pretty);
@@ -1078,8 +1079,8 @@ For debugging.
 
 sub variables_dump ()
 {
-  my $text = "All variables:\n{\n";
-  foreach my $var (sort { $a->name cmp $b->name } variables)
+  my $text = "all variables:\n{\n";
+  foreach my $var (variables())
     {
       $text .= $var->dump;
     }
@@ -1142,7 +1143,7 @@ sub require_variables ($$$@)
       next VARIABLE
 	if vardef ($var, $cond);
 
-      my $text = "$reason`$var' is undefined\n";
+      my $text = "$reason'$var' is undefined\n";
       my $v = var $var;
       if ($v)
 	{
@@ -1159,20 +1160,20 @@ sub require_variables ($$$@)
       if (exists $_am_macro_for_var{$var})
 	{
 	  my $mac = $_am_macro_for_var{$var};
-	  $text .= "  The usual way to define `$var' is to add "
-	    . "`$mac'\n  to `$configure_ac' and run `aclocal' and "
-	    . "`autoconf' again.";
+	  $text .= "  The usual way to define '$var' is to add "
+	    . "'$mac'\n  to '$configure_ac' and run 'aclocal' and "
+	    . "'autoconf' again.";
 	  # aclocal will not warn about undefined macros unless it
 	  # starts with AM_.
-	  $text .= "\n  If `$mac' is in `$configure_ac', make sure\n"
+	  $text .= "\n  If '$mac' is in '$configure_ac', make sure\n"
 	    . "  its definition is in aclocal's search path."
 	    unless $mac =~ /^AM_/;
 	}
       elsif (exists $_ac_macro_for_var{$var})
 	{
-	  $text .= "  The usual way to define `$var' is to add "
-	    . "`$_ac_macro_for_var{$var}'\n  to `$configure_ac' and "
-	    . "run `autoconf' again.";
+	  $text .= "  The usual way to define '$var' is to add "
+	    . "'$_ac_macro_for_var{$var}'\n  to '$configure_ac' and "
+	    . "run 'autoconf' again.";
 	}
 
       error $where, $text, uniq_scope => US_GLOBAL;
@@ -1314,7 +1315,7 @@ recursive calls).
 
 =cut
 
-# Contains a stack of `from' and `to' parts of variable
+# Contains a stack of 'from' and 'to' parts of variable
 # substitutions currently in force.
 my @_substfroms;
 my @_substtos;
@@ -1343,7 +1344,7 @@ sub _do_recursive_traversal ($$&&$$$$)
 
   if ($var->{'scanned'} == $_traversal)
     {
-      err_var $var, "variable `" . $var->name() . "' recursively defined";
+      err_var $var, "variable '" . $var->name() . "' recursively defined";
       return ();
     }
   $var->{'scanned'} = $_traversal;
@@ -1372,7 +1373,7 @@ sub _do_recursive_traversal ($$&&$$$$)
 	  my $val = shift @to_process;
 	  # If $val is a variable (i.e. ${foo} or $(bar), not a filename),
 	  # handle the sub variable recursively.
-	  # (Backslashes before `}' and `)' within brackets are here to
+	  # (Backslashes before '}' and ')' within brackets are here to
 	  # please Emacs's indentation.)
 	  if ($val =~ /^\$\{([^\}]*)\}$/ || $val =~ /^\$\(([^\)]*)\)$/)
 	    {
@@ -1414,7 +1415,7 @@ sub _do_recursive_traversal ($$&&$$$$)
 	      next;
 	    }
 	  # Try to expand variable references inside filenames such as
-	  # `$(NAME).txt'.  We do not handle `:.foo=.bar'
+	  # '$(NAME).txt'.  We do not handle ':.foo=.bar'
 	  # substitutions, but it would make little sense to use this
 	  # here anyway.
 	  elsif ($inner_expand
